---
title: "BMP280"
linkTitle: "BMP280"
weight: 4
description: >
  Bosch Digital Pressure Sensor
---

## Registers

### Digital Pressure Compensation 1
Used for Pascals conversion

### Digital Pressure Compensation 2
Used for Pascals conversion

### Digital Pressure Compensation 3
Used for Pascals conversion

### Digital Pressure Compensation 4
Used for Pascals conversion

### Digital Pressure Compensation 5
Used for Pascals conversion

### Digital Pressure Compensation 6
Used for Pascals conversion

### Digital Pressure Compensation 7
Used for Pascals conversion

### Digital Pressure Compensation 8
Used for Pascals conversion

### Digital Pressure Compensation 9
Used for Pascals conversion

### Digital Temperature Compensation 1
Used for Celcius conversion

### Digital Temperature Compensation 2
Used for Celcius conversion

### Digital Temperature Compensation 3
Used for Celcius conversion

### Pressure LSB
Part 2 of Pressure

### Pressure MSB
Part 1 of Pressure

### Pressure XLSB
Part 3 of Pressure

### Temperature LSB
Part 2 of temperature

### Temperature MSB
Part 1 of temperature

### Temperature XLSB
Final part of temperature

## License
Licensed under [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html#licenseText).

_BMP280 version 0.1.0_

_Based on Cyanobyte spec version 0.1.0_

_Generated from Cyanobyte Codegen version 0.1.0_